@@ -5,7 +5,7 @@ require 'spec_helper'
 
 describe 'sahara::client' do
 
-  shared_examples_for 'sahara client' do
+  shared_examples 'sahara client' do
 
     it { is_expected.to contain_class('sahara::deps') }
     it { is_expected.to contain_class('sahara::params') }
