@@ -5,7 +5,7 @@
 require 'spec_helper'
 
 describe 'sahara::keystone::auth' do
-  shared_examples_for 'sahara::keystone::auth' do
+  shared_examples 'sahara::keystone::auth' do
     context 'with default class parameters' do
       let :params do
         { :password => 'sahara_password' }
@@ -23,6 +23,9 @@ describe 'sahara::keystone::auth' do
         :password            => 'sahara_password',
         :email               => 'sahara@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8386',
         :internal_url        => 'http://127.0.0.1:8386',
         :admin_url           => 'http://127.0.0.1:8386',
@@ -35,6 +38,9 @@ describe 'sahara::keystone::auth' do
           :auth_name           => 'alt_sahara',
           :email               => 'alt_sahara@alt_localhost',
           :tenant              => 'alt_service',
+          :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
@@ -59,6 +65,9 @@ describe 'sahara::keystone::auth' do
         :password            => 'sahara_password',
         :email               => 'alt_sahara@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
